import fs from 'fs/promises';
import type { Stats } from 'fs';
import { Hashes } from '../hash';
import { basename } from 'path';

interface SequenceObject {
	path : string,
	hash : string,
	name : string
}

export class Files {
	public static async exists (path : string) : Promise<boolean> {  
		try {
			await fs.access(path);
			return true;
		} catch {
			return false;
		}
	}

	public static async enumerateSequences (path : string) : Promise<SequenceObject[]> {
		const dirs : SequenceObject[] = [];
		let all : string[];
		let stats : Stats;
		try {
			all = await fs.readdir(path)
		} catch (err) {
			throw err;
		}

		for (let elem of all) {
			try {
				stats = await fs.lstat(elem);
    			if (stats.isDirectory()) {
    				dirs.push({
    					path : elem,
    					hash : Hashes.stringHash(elem),
    					name : basename(elem)
    				});
    			}
			} catch (err) {
				//
			}
		}

		return dirs;
	}
}

export type { SequenceObject };
module.exports = { Files };
